@@ -60,6 +60,7 @@ define ([
             containsFunc(assert, htmlbuf, "#result", 'AJAX call');
         },
         containsFunc = function (assert, lookIn, lookInDesc, lookFor) {
+            // console.log("containsFunc() looking for ->" + lookFor + "<- in ->" + lookIn + "<-");
             // asserts that the string lookIn contains substring lookFor
             // lookInDesc describes what lookIn represents
             assert.notStrictEqual(
@@ -203,7 +204,7 @@ define ([
             assert.ok(cu.obj, "currentUserObj after logout: " + QUnit.dump.parse(cu));
             assert.strictEqual(cu.obj.nick, null, 'Current user object reset to null');
             assert.strictEqual(cu.priv, null, 'Current user priv reset to null');
-            containsFunc(assert, $('#mainarea').html(), "#mainarea", 'You have been logged out');
+            containsFunc(assert, $('#mainarea').html(), "#mainarea", 'You have logged out');
         },
 
         "login": function (assert, nick, priv) {
@@ -276,7 +277,7 @@ define ([
                 assert,
                 htmlbuf,
                 "#mainarea html",
-                "0. Search"
+                "0.&nbsp;Search"
             );
             assert.ok(
                 $('#searchEmployee input[name="entry0"]'),
