@@ -44,39 +44,6 @@ define ([
 
     return function () {
 
-        target.push('browseInt', {
-            'name': 'browseInt',
-            'type': 'dmenu',
-            'menuText': 'Browse',
-            'title': 'Browse intervals',
-            'aclProfile': 'inactive',
-            'entries': ['browseIntDay', 'browseIntWeek', 'browseIntMonth',],
-        });
-        target.push('browseIntDay', {
-            'name': 'browseIntDay',
-            'type': 'dmenu',
-            'menuText': 'By day',
-            'title': 'Browse intervals by day',
-            'aclProfile': 'inactive',
-            'entries': ['browseIntToday', 'browseIntYesterday', 'browseIntAnyday',],
-        });
-        target.push('browseIntWeek', {
-            'name': 'browseIntWeek',
-            'type': 'dmenu',
-            'menuText': 'By week',
-            'title': 'Browse intervals by week',
-            'aclProfile': 'inactive',
-            'entries': ['browseIntThisWeek', 'browseIntLastWeek', 'browseIntAnyWeek',],
-        });
-        target.push('browseIntMonth', {
-            'name': 'browseIntMonth',
-            'type': 'dmenu',
-            'menuText': 'By month',
-            'title': 'Browse intervals by month',
-            'aclProfile': 'inactive',
-            'entries': ['browseIntThisMonth', 'browseIntLastMonth', 'browseIntAnyMonth',],
-        });
-
         target.push('createInt', {
             'name': 'createInt',
             'type': 'dmenu',
@@ -101,7 +68,7 @@ define ([
             'menuText': 'Employee',
             'title': 'Employee menu',
             'aclProfile': 'passerby',
-            'entries': ['myProfileAction', 'ldapLookup', 'searchEmployee', 'masqEmployee']
+            'entries': ['myProfileAction', 'ldapLookup', 'searchEmployee']
         });
 
         target.push('mainInt', {
@@ -110,7 +77,7 @@ define ([
             'menuText': 'Interval',
             'title': 'Interval menu',
             'aclProfile': 'passerby',
-            'entries': ['browseInt', 'createInt'],
+            'entries': ['viewIntervalsPrep', 'createInt'],
         });
 
         target.push('mainMenu', {
@@ -119,7 +86,8 @@ define ([
             'menuText': 'Main',
             'title': 'Main menu',
             'aclProfile': 'passerby',
-            'entries': ['mainEmpl', 'mainPriv', 'mainSched', 'mainInt', 'mainAdmin']
+            'entries': ['mainEmpl', 'mainPriv', 'mainSched', 'mainInt', 'masqEmployee',
+                        'mainAdmin']
         });
 
         target.push('mainPriv', {
