@@ -37,15 +37,13 @@
 "use strict";
 
 define ([
-    'app/lib',
-    'target'
+    'app/entries',
+    'target',
 ], function (
-    appLib,
-    target
+    entries,
+    target,
 ) {
 
-    var entries = appLib.entries;
-
     return function () {
 
         target.push('privHistoryDtable', {
@@ -55,7 +53,7 @@ define ([
             'title': 'Privilege (status) history',
             'preamble': null,
             'aclProfile': 'passerby',
-            'entries': [entries.ePnick, entries.pHeffective, entries.pHpriv],
+            'entriesRead': [entries.ePnick, entries.pHeffective, entries.pHpriv],
             'miniMenu': {
                 entries: ['actionPrivHistoryEdit']
             }
@@ -68,11 +66,25 @@ define ([
             'title': 'Schedule history',
             'preamble': null,
             'aclProfile': 'passerby',
-            'entries': [entries.pHeffective, entries.sDid, entries.sDcode],
+            'entriesRead': [entries.pHeffective, entries.sDid, entries.sDcode],
             'miniMenu': {
                 entries: ['actionSchedHistoryEdit']
             }
         });
 
+        target.push('viewIntervalsDtable', {
+            'name': 'viewIntervalsDtable',
+            'type': 'dtable',
+            'menuText': 'View',
+            'title': 'Intervals in date range',
+            'preamble': null,
+            'aclProfile': 'passerby',
+            'entriesRead': [entries.iNdate, entries.iNtimerange, entries.iNiid, entries.acTcode],
+            'miniMenu': {
+                entries: null,
+            }
+        }); // viewIntervalsDtable
+
     };
+
 });
