@@ -60,8 +60,10 @@ define ([
     stack,
 ) {
 
-    var 
+    var empProfileEmp,
+
         actionEmplSearch = function (obj) {
+            var count, masquerade, opts, rs, supervisor;
             // obj is searchKeyNick from the form
             if (! obj) {
                 obj = stack.getState();
@@ -77,15 +79,29 @@ define ([
         
                         // if only one record is returned, it might be in a result_set
                         // or it might be alone in the payload
-                        var rs = st.payload.result_set || st.payload,
-                            count = rs.length;
+                        rs = st.payload.result_set || st.payload;
+                        count = rs.length;
+                        opts = stack.getOpts();
+                        masquerade = ('masquerade' in opts) ? opts.masquerade : false;
+                        supervisor = ('supervisor' in opts) ? opts.supervisor : false;
         
                         console.log("Search found " + count + " employees");
-                        stack.push(
-                            "simpleEmployeeBrowser",
-                            {"set": rs, "pos": 0},
-                            {"flag": true},
-                        );
+                        if (masquerade) {
+                            stack.push(
+                                "masqueradeCandidatesBrowser",
+                                {"set": rs, "pos": 0},
+                            );
+                        } else if (supervisor) {
+                            stack.push(
+                                "setSupervisorBrowser",
+                                {"set": rs, "pos": 0},
+                            );
+                        } else {
+                            stack.push(
+                                "simpleEmployeeBrowser",
+                                {"set": rs, "pos": 0},
+                            );
+                        }
                     } else {
                         coreLib.displayError("Unexpected status code " + st.code);
                     }
@@ -143,6 +159,59 @@ define ([
             ajax(rest, sc, fc);
         },
 
+        empProfileSetSuperChoose = function (superEmp) {
+            var cu = currentUser('obj'),
+                obj = {
+                    "ePsetsuperofEID": cu.eid,
+                    "ePsetsupertoEID": superEmp.eid,
+                    "ePsetsuperof": cu.nick,
+                    "ePsetsuperto": superEmp.nick,
+                };
+            console.log("Entering empSetSupervisor() with superEmp", superEmp);
+            console.log("Will set superEmp as the supervisor of " + cu.nick);
+            console.log("Pushing empProfileSetSuperConfirm onto stack with obj", obj);
+            stack.push('empProfileSetSuperConfirm', obj);
+        },
+
+        empProfileSetSuperCommit = function (obj) {
+            var cu = currentUser('obj'),
+                empProfile,
+                rest = {
+                    "method": 'PUT',
+                    "path": 'employee/eid/' + obj.ePsetsuperofEID,
+                    "body": {
+                        "supervisor": obj.ePsetsupertoEID,
+                    }
+                },
+                sc = function (st) {
+                    if (st.code === 'DOCHAZKA_CUD_OK') {
+                        cu.supervisor = obj.ePsetsupertoEID;
+                        empProfile = appCaches.getProfileByEID(obj.ePsetsuperofEID);
+                        if (empProfile) {
+                             empProfile.supervisor = obj.ePsetsupertoEID;
+                             appCaches.setProfileByEID(obj.ePsetsuperofEID, empProfile);
+                        }
+                        stack.unwindToType('dmenu', {
+                            "_start": false
+                        });
+                        stack.push('myProfileAction', {
+                            "resultLine": "Commit OK"
+                        });
+                    } else {
+                        coreLib.displayError("CRITICAL ERROR THIS IS A BUG: " + st.code);
+                    }
+                };
+            console.log("Entered empProfileSetSuperCommit() with obj", obj);
+            ajax(rest, sc);
+        },
+
+        empProfileSetSuperSearch = function (superEmp) {
+            empProfileEmp = superEmp;
+            stack.push('searchEmployee', {}, {
+                "supervisor": true,
+            });
+        },
+
         myProfileAction = function () {
             var cu = currentUser('obj'),
                 profileObj = appCaches.getProfileByEID(cu.eid),
@@ -155,7 +224,7 @@ define ([
                 coreLib.displayError(m);
                 return null;
             }
-            if (profileObj.privhistory !== null) {
+            if (profileObj.privhistory) {
                 obj['priv'] = profileObj.privhistory.priv;
                 obj['privEffective'] = datetime.readableDate(
                     profileObj.privhistory.effective
@@ -164,7 +233,7 @@ define ([
                 obj['priv'] = '(none)';
                 obj['privEffective'] = '(none)';
             }
-            if (profileObj.schedhistory !== null) {
+            if (profileObj.schedhistory) {
                 obj['sid'] = profileObj.schedhistory.sid;
                 if (profileObj.schedhistory.scode !== null) {
                     obj['scode'] = profileObj.schedhistory.scode;
@@ -184,13 +253,16 @@ define ([
             obj['fullname'] = profileObj.emp.fullname;
             obj['email'] = profileObj.emp.email;
             obj['remark'] = profileObj.emp.remark;
-            obj['sec_id'] - profileObj.emp.sec_id;
+            obj['sec_id'] = profileObj.emp.sec_id;
             stack.push('empProfile', obj);
         };
 
     return {
         actionEmplSearch: actionEmplSearch,
         empProfileEditSave: empProfileEditSave,
+        empProfileSetSuperChoose: empProfileSetSuperChoose,
+        empProfileSetSuperCommit: empProfileSetSuperCommit,
+        empProfileSetSuperSearch: empProfileSetSuperSearch,
         myProfileAction: myProfileAction,
     };
 
