@@ -39,63 +39,43 @@
 define ([
     'app/caches',
     'app/act-lib',
+    'app/int-lib',
     'datetime',
 ], function (
-    appCaches,
+    caches,
     actLib,
+    intLib,
     datetime,
 ) {
 
     return {
 
-        ePnick: {
-            name: 'ePnick',
-            aclProfileRead: 'passerby',
+        acTaid: {
+            name: 'acTaid',
+            aclProfileRead: 'active',
             aclProfileWrite: 'active',
-            text: 'Nick',
-            prop: 'nick',
-            maxlen: 20,
+            text: 'AID',
+            prop: 'aid',
+            hidden: true,
+            maxlen: 6,
+            populate: caches.populateAIDfromCode,
         },
-        ePsec_id: {
-            name: 'ePsec_id',
-            aclProfileRead: 'passerby',
-            aclProfileWrite: null,
-            text: 'Workforce ID',
-            prop: 'sec_id',
-            maxlen: 8,
-        },
-        ePfullname: {
-            name: 'ePfullname',
-            aclProfileRead: 'passerby',
+        acTcode: {
+            name: 'acTcode',
+            aclProfileRead: 'active',
             aclProfileWrite: 'active',
-            text: 'Full name',
-            prop: 'fullname',
-            maxlen: 55,
-        },
-        ePemail: {
-            name: 'ePemail',
-            aclProfileRead: 'passerby',
-            aclProfileWrite: 'active',
-            text: 'Email',
-            prop: 'email',
-            maxlen: 55,
-        },
-        ePremark: {
-            name: 'ePremark',
-            aclProfileRead: 'admin',
-            aclProfileWrite: 'admin',
-            text: 'Remark',
-            prop: 'remark',
-            maxlen: 55,
-        },
-        ePpriv: {
-            name: 'ePpriv',
-            aclProfileRead: 'inactive',
-            aclProfileWrite: 'admin',
-            text: 'Status',
-            prop: 'priv',
+            text: 'Activity',
+            prop: 'code',
             maxlen: 10,
         },
+        acTdesc: {
+            name: 'acTdesc',
+            aclProfileRead: 'active',
+            aclProfileWrite: 'active',
+            text: 'Description',
+            prop: 'long_desc',
+            maxlen: 40,
+        },
         ePeffective: {
             name: 'ePeffective',
             aclProfileRead: 'inactive',
@@ -104,6 +84,39 @@ define ([
             prop: 'effective',
             maxlen: 30,
         },
+        ePemail: {
+            name: 'ePemail',
+            aclProfileRead: 'passerby',
+            aclProfileWrite: 'active',
+            text: 'Email',
+            prop: 'email',
+            maxlen: 55,
+        },
+        ePfullname: {
+            name: 'ePfullname',
+            aclProfileRead: 'passerby',
+            aclProfileWrite: 'active',
+            text: 'Full name',
+            prop: 'fullname',
+            maxlen: 55,
+        },
+        ePnick: {
+            name: 'ePnick',
+            aclProfileRead: 'passerby',
+            aclProfileWrite: 'active',
+            text: 'Nick',
+            prop: 'nick',
+            maxlen: 20,
+        },
+        ePpriv: {
+            name: 'ePpriv',
+            aclProfileRead: 'inactive',
+            aclProfileWrite: 'admin',
+            text: 'Status',
+            prop: 'priv',
+            maxlen: 10,
+            // populate: empLib.populateProfilePriv,
+        },
         ePprivEffective: {
             name: 'ePprivEffective',
             aclProfileRead: 'inactive',
@@ -111,6 +124,23 @@ define ([
             text: 'Status since',
             prop: 'privEffective',
             maxlen: 30,
+            // populate: empLib.populateProfilePrivEffective,
+        },
+        ePremark: {
+            name: 'ePremark',
+            aclProfileRead: 'admin',
+            aclProfileWrite: 'admin',
+            text: 'Remark',
+            prop: 'remark',
+            maxlen: 55,
+        },
+        ePschedEffective: {
+            name: 'ePschedEffective',
+            aclProfileRead: 'inactive',
+            aclProfileWrite: 'admin',
+            text: 'Schedule since',
+            prop: 'schedEffective',
+            maxlen: 30,
         },
         ePscode: {
             name: 'ePscode',
@@ -120,6 +150,48 @@ define ([
             prop: 'scode',
             maxlen: 20,
         },
+        ePsec_id: {
+            name: 'ePsec_id',
+            aclProfileRead: 'passerby',
+            aclProfileWrite: null,
+            text: 'Workforce ID',
+            prop: 'sec_id',
+            maxlen: 8,
+        },
+        ePsetsuperof: {
+            name: 'ePsetsuperof',
+            aclProfileRead: 'admin',
+            aclProfileWrite: null,
+            text: 'Supervisor of employee',
+            prop: 'ePsetsuperof',
+            maxlen: 32,
+        },
+        ePsetsuperofEID: {
+            name: 'ePsetsuperofEID',
+            aclProfileRead: 'admin',
+            aclProfileWrite: null,
+            text: 'ePsetsuperofEID',
+            prop: 'ePsetsuperofEID',
+            hidden: true,
+            maxlen: 32,
+        },
+        ePsetsuperto: {
+            name: 'ePsetsuperto',
+            aclProfileRead: 'admin',
+            aclProfileWrite: null,
+            text: 'will be changed to',
+            prop: 'ePsetsuperto',
+            maxlen: 32,
+        },
+        ePsetsupertoEID: {
+            name: 'ePsetsupertoEID',
+            aclProfileRead: 'admin',
+            aclProfileWrite: null,
+            text: 'ePsetsupertoEID',
+            prop: 'ePsetsupertoEID',
+            hidden: true,
+            maxlen: 32,
+        },
         ePsid: {
             name: 'ePsid',
             aclProfileRead: 'inactive',
@@ -128,14 +200,6 @@ define ([
             prop: 'sid',
             maxlen: 20,
         },
-        ePschedEffective: {
-            name: 'ePschedEffective',
-            aclProfileRead: 'inactive',
-            aclProfileWrite: 'admin',
-            text: 'Schedule since',
-            prop: 'schedEffective',
-            maxlen: 30,
-        },
         ePsuperNick: {
             name: 'ePsuperNick',
             aclProfileRead: 'inactive',
@@ -143,7 +207,209 @@ define ([
             text: 'Supervisor',
             prop: 'ePsuperNick',
             maxlen: 30,
-            populate: appCaches.populateSupervisorNick,
+            populate: caches.populateSupervisorNick,
+        },
+        iNact: {
+            name: 'iNact',
+            aclProfileRead: 'active',
+            aclProfileWrite: 'active',
+            text: 'Activity',
+            prop: 'iNact',
+            maxlen: 32,
+            vetter: actLib.vetActivity,
+        },
+        iNactHidden: {
+            name: 'iNact',
+            aclProfileRead: 'active',
+            aclProfileWrite: 'admin',
+            text: 'Activity',
+            prop: 'iNact',
+            hidden: true,
+            maxlen: 20,
+        },
+        iNdate: {
+            name: 'iNdate',
+            aclProfileRead: 'active',
+            aclProfileWrite: 'active',
+            text: 'Date',
+            prop: 'iNdate',
+            maxlen: 20,
+            vetter: datetime.vetDate,
+        },
+        iNdateHidden: {
+            name: 'iNdate',
+            aclProfileRead: 'active',
+            aclProfileWrite: 'admin',
+            text: 'Date',
+            prop: 'iNdate',
+            hidden: true,
+            maxlen: 20,
+        },
+        iNdaterange: {
+            name: 'iNdaterange',
+            aclProfileRead: 'active',
+            aclProfileWrite: 'active',
+            text: 'Date range',
+            prop: 'iNdaterange',
+            maxlen: 30,
+            vetter: datetime.vetDateRange,
+        },
+        iNdaterangeBegin: {
+            name: 'iNdaterangeBegin',
+            aclProfileRead: 'active',
+            aclProfileWrite: 'admin',
+            text: 'Date',
+            prop: 'iNdaterangeBegin',
+            hidden: true,
+            maxlen: 20,
+        },
+        iNdaterangeEnd: {
+            name: 'iNdaterangeEnd',
+            aclProfileRead: 'active',
+            aclProfileWrite: 'admin',
+            text: 'Date',
+            prop: 'iNdaterangeEnd',
+            hidden: true,
+            maxlen: 20,
+        },
+        iNdaylist: {
+            name: 'iNdaylist',
+            aclProfileRead: 'active',
+            aclProfileWrite: 'active',
+            text: 'Day(s)',
+            prop: 'iNdaylist',
+            maxlen: 120,
+            size: 60,
+            vetter: intLib.vetDayList,
+        },
+        iNdayrange: {
+            name: 'iNdayrange',
+            aclProfileRead: 'inactive',
+            aclProfileWrite: 'inactive',
+            text: 'Day(s)',
+            prop: 'iNdayrange',
+            maxlen: 20,
+            vetter: intLib.vetDayRange,
+        },
+        iNdesc: {
+            name: 'iNdesc',
+            aclProfileRead: 'active',
+            aclProfileWrite: 'active',
+            text: 'Description',
+            prop: 'iNdesc',
+            maxlen: 60,
+        },
+        iNexistintvls: {
+            name: 'iNexistintvls',
+            aclProfileRead: 'inactive',
+            aclProfileWrite: 'admin',
+            text: 'Existing',
+            prop: 'iNexistintvls',
+            maxlen: 50,
+            populate: caches.populateExistingIntervals,
+        },
+        iNiid: {
+            name: 'iNiid',
+            aclProfileRead: 'inactive',
+            aclProfileWrite: 'admin',
+            text: 'IID',
+            prop: 'iid',
+            maxlen: 8,
+        },
+        iNlastexistintvl: {
+            name: 'iNlastexistintvl',
+            aclProfileRead: 'inactive',
+            aclProfileWrite: 'admin',
+            text: 'Last existing',
+            prop: 'iNlastexistintvl',
+            maxlen: 50,
+            populate: caches.populateLastExisting,
+        },
+        iNlastplusoffset: {
+            name: 'iNlastplusoffset',
+            aclProfileRead: 'inactive',
+            aclProfileWrite: 'admin',
+            text: 'Time range',
+            prop: 'iNlastplusoffset',
+            maxlen: 50,
+            populate: caches.populateLastPlusOffset,
+        },
+        iNmonth: {
+            name: 'iNmonth',
+            aclProfileRead: 'active',
+            aclProfileWrite: 'active',
+            text: 'Month',
+            prop: 'iNmonth',
+            maxlen: 20,
+            vetter: datetime.vetMonth,
+        },
+        iNnextscheduled: {
+            name: 'iNnextscheduled',
+            aclProfileRead: 'inactive',
+            aclProfileWrite: 'admin',
+            text: 'To be created',
+            prop: 'iNnextscheduled',
+            maxlen: 50,
+            populate: caches.populateNextScheduled,
+        },
+        iNoffset: {
+            name: 'iNoffset',
+            aclProfileRead: 'inactive',
+            aclProfileWrite: 'admin',
+            text: 'Offset',
+            prop: 'iNoffset',
+            maxlen: 20,
+        },
+        iNschedintvls: {
+            name: 'iNschedintvls',
+            aclProfileRead: 'inactive',
+            aclProfileWrite: 'admin',
+            text: 'Scheduled',
+            prop: 'iNschedintvls',
+            maxlen: 50,
+            populate: caches.populateSchedIntvlsForDate,
+        },
+        iNsid: {
+            name: 'iNsid',
+            aclProfileRead: 'inactive',
+            aclProfileWrite: 'admin',
+            text: 'Schedule ID',
+            prop: 'iNsid',
+            hidden: true,
+            maxlen: 20,
+            populate: caches.populateSIDByDate,
+        },
+        iNtimerange: {
+            name: 'iNtimerange',
+            aclProfileRead: 'active',
+            aclProfileWrite: 'active',
+            text: 'Time range',
+            prop: 'iNtimerange',
+            maxlen: 20,
+            vetter: datetime.vetTimeRange,
+        },
+        iNtoBeCreated: {
+            name: 'textOnly',
+            textOnly: "Interval to be created",
+        },
+        iNyear: {
+            name: 'iNyear',
+            aclProfileRead: 'active',
+            aclProfileWrite: 'active',
+            text: 'Year',
+            prop: 'iNyear',
+            maxlen: 5,
+            vetter: datetime.vetYear,
+        },
+        iNyearHidden: {
+            name: 'iNyear',
+            aclProfileRead: 'active',
+            aclProfileWrite: 'active',
+            text: 'Year',
+            prop: 'iNyear',
+            hidden: true,
+            maxlen: 5,
+            populate: caches.populateYear,
         },
         LDAPdochazka: {
             name: 'LDAPdochazka',
@@ -153,14 +419,6 @@ define ([
             prop: 'dochazka',
             maxlen: 30,
         },
-        sEnick: {
-            name: 'sEnick',
-            aclProfileRead: null,
-            aclProfileWrite: 'admin',
-            text: 'Nick',
-            prop: 'searchKeyNick',
-            maxlen: 20,
-        },
         pHpriv: {
             name: 'pHpriv',
             aclProfileRead: 'passerby',
@@ -192,21 +450,13 @@ define ([
             prop: 'version',
             maxlen: 30,
         },
-        sScode: {
-            name: 'sScode',
-            aclProfileRead: null,
-            aclProfileWrite: 'inactive',
-            text: 'Schedule code',
-            prop: 'searchKeySchedCode',
-            maxlen: 20,
-        },
-        sSid: {
-            name: 'sSid',
-            aclProfileRead: null,
-            aclProfileWrite: 'inactive',
-            text: 'Schedule ID',
-            prop: 'searchKeySchedID',
-            maxlen: 20,
+        sCboiler: {
+            name: 'sCboiler',
+            aclProfileRead: 'admin',
+            aclProfileWrite: 'admin',
+            text: 'Intervals',
+            prop: 'boilerplate',
+            maxlen: 50,
         },
         sDcode: {
             name: 'sDcode',
@@ -216,6 +466,14 @@ define ([
             prop: 'scode',
             maxlen: 20,
         },
+        sDdisabled: {
+            name: 'sDdisabled',
+            aclProfileRead: 'admin',
+            aclProfileWrite: 'admin',
+            text: 'Disabled?',
+            prop: 'disabled',
+            maxlen: 10,
+        },
         sDid: {
             name: 'sDid',
             aclProfileRead: 'inactive',
@@ -280,21 +538,13 @@ define ([
             prop: 'sun',
             maxlen: 50,
         },
-        sDdisabled: {
-            name: 'sDdisabled',
-            aclProfileRead: 'admin',
+        sEnick: {
+            name: 'sEnick',
+            aclProfileRead: null,
             aclProfileWrite: 'admin',
-            text: 'Disabled?',
-            prop: 'disabled',
-            maxlen: 10,
-        },
-        sCboiler: {
-            name: 'sCboiler',
-            aclProfileRead: 'admin',
-            aclProfileWrite: 'admin',
-            text: 'Intervals',
-            prop: 'boilerplate',
-            maxlen: 50,
+            text: 'Nick',
+            prop: 'searchKeyNick',
+            maxlen: 20,
         },
         sHid: {
             name: 'sHid',
@@ -304,129 +554,21 @@ define ([
             prop: 'shid',
             maxlen: 20,
         },
-        iNdate: {
-            name: 'iNdate',
-            aclProfileRead: 'active',
-            aclProfileWrite: 'active',
-            text: 'Interval date',
-            prop: 'iNdate',
+        sScode: {
+            name: 'sScode',
+            aclProfileRead: null,
+            aclProfileWrite: 'inactive',
+            text: 'Schedule code',
+            prop: 'searchKeySchedCode',
             maxlen: 20,
-            vetter: datetime.vetDate,
         },
-        iNdaterange: {
-            name: 'iNdaterange',
-            aclProfileRead: 'active',
-            aclProfileWrite: 'active',
-            text: 'Date range',
-            prop: 'iNdaterange',
-            maxlen: 30,
-            vetter: datetime.vetDateRange,
-        },
-        iNtimerange: {
-            name: 'iNtimerange',
-            aclProfileRead: 'active',
-            aclProfileWrite: 'active',
-            text: 'Time range',
-            prop: 'iNtimerange',
-            maxlen: 20,
-            vetter: datetime.vetTimeRange,
-        },
-        iNact: {
-            name: 'iNact',
-            aclProfileRead: 'active',
-            aclProfileWrite: 'active',
-            text: 'Activity',
-            prop: 'iNact',
-            maxlen: 20,
-            vetter: actLib.vetActivity,
-        },
-        iNdesc: {
-            name: 'iNdesc',
-            aclProfileRead: 'active',
-            aclProfileWrite: 'active',
-            text: 'Description',
-            prop: 'iNdesc',
-            maxlen: 60,
-        },
-        iNsid: {
-            name: 'iNsid',
-            aclProfileRead: 'inactive',
-            aclProfileWrite: 'admin',
+        sSid: {
+            name: 'sSid',
+            aclProfileRead: null,
+            aclProfileWrite: 'inactive',
             text: 'Schedule ID',
-            prop: 'iNsid',
+            prop: 'searchKeySchedID',
             maxlen: 20,
-            populate: appCaches.populateSIDByDate,
-        },
-        iNoffset: {
-            name: 'iNoffset',
-            aclProfileRead: 'inactive',
-            aclProfileWrite: 'admin',
-            text: 'Offset',
-            prop: 'iNoffset',
-            maxlen: 20,
-        },
-        acTcode: {
-            name: 'acTcode',
-            aclProfileRead: 'active',
-            aclProfileWrite: 'active',
-            text: 'Activity Code',
-            prop: 'code',
-            maxlen: 10,
-        },
-        acTaid: {
-            name: 'acTaid',
-            aclProfileRead: 'active',
-            aclProfileWrite: 'active',
-            text: 'Activity ID',
-            prop: 'aid',
-            maxlen: 6,
-            populate: appCaches.populateAIDfromCode,
-        },
-        acTdesc: {
-            name: 'acTdesc',
-            aclProfileRead: 'active',
-            aclProfileWrite: 'active',
-            text: 'Description',
-            prop: 'long_desc',
-            maxlen: 40,
-        },
-        iNschedintvls: {
-            name: 'iNschedintvls',
-            aclProfileRead: 'inactive',
-            aclProfileWrite: 'admin',
-            text: 'Scheduled',
-            prop: 'iNschedintvls',
-            maxlen: 50,
-            populate: appCaches.populateSchedIntvlsForDate,
-        },
-        iNlastexistintvl: {
-            name: 'iNlastexistintvl',
-            aclProfileRead: 'inactive',
-            aclProfileWrite: 'admin',
-            text: 'Last existing',
-            prop: 'iNlastexistintvl',
-            maxlen: 50,
-            populate: appCaches.populateLastExisting,
-        },
-        iNlastplusoffset: {
-            name: 'iNlastplusoffset',
-            aclProfileRead: 'inactive',
-            aclProfileWrite: 'admin',
-            text: 'To be created',
-            prop: 'iNlastplusoffset',
-            maxlen: 50,
-            populate: appCaches.populateLastPlusOffset,
-        },
-        iNnextscheduled: {
-            name: 'iNnextscheduled',
-            aclProfileRead: 'inactive',
-            aclProfileWrite: 'admin',
-            text: 'To be created',
-            prop: 'iNnextscheduled',
-            maxlen: 50,
-            populate: function () {
-                // TBD
-            },
         },
 
     };
